package com.lantone.qc.trans.changx;

import com.google.common.collect.Lists;
import com.lantone.qc.pub.model.doc.operation.OperationDiscussionDoc;
import com.lantone.qc.pub.model.doc.operation.OperationDoc;
import com.lantone.qc.pub.model.doc.operation.PreoperativeDiscussionDoc;
import com.lantone.qc.pub.model.keys.ModelStandardKeys;
import com.lantone.qc.pub.model.vo.MedrecVo;
import com.lantone.qc.pub.util.ListUtil;
import com.lantone.qc.trans.ModelDocTrans;
import com.lantone.qc.trans.comsis.ModelDocGenerate;
import com.lantone.qc.trans.comsis.Preproc;

import java.util.List;
import java.util.Map;

/**
 * @Description: 手术文档生成
 * @author: rengb
 * @time: 2020/3/20 17:11
 */
public class ChangxOperationDocTrans extends ModelDocTrans {

    @Override
    public List<OperationDoc> extract(MedrecVo medrecVo) {
        List<OperationDoc> retList = Lists.newArrayList();
        Map<String, Object> content = medrecVo.getContent();
        Map<String, List<String>> labelMap = (Map) content.get("label");
        List<String> operationDiscussionLabel = labelMap.get("术后首次病程及谈话记录");
        List<String> preoperativeDiscussionLabel = labelMap.get("术前讨论、术前小结");
        List<Map<String, String>> operations = (List) content.get("content");

        String operationDiscussionContent, preoperativeDiscussionContent;
        Map<String, String> operationDiscussionStructureMap, preoperativeDiscussionStructureMap;
        for (Map<String, String> operation : operations) {
            OperationDoc operationDoc = new OperationDoc();

            operationDiscussionContent = operation.get("术后首次病程及谈话记录");
            operationDiscussionStructureMap =
                    Preproc.extract_doc_pub(
                            false,
                            ListUtil.isEmpty(operationDiscussionLabel) ? ModelStandardKeys.operationDiscussion : operationDiscussionLabel,
                            operationDiscussionContent
                    );
            OperationDiscussionDoc operationDiscussionDoc = ModelDocGenerate.operationDiscussionDocGen(operationDiscussionStructureMap);
            operationDiscussionDoc.setText(operationDiscussionContent);
            operationDoc.setOperationDiscussionDoc(operationDiscussionDoc);

            preoperativeDiscussionContent = operation.get("术前讨论、术前小结");
            preoperativeDiscussionStructureMap =
                    Preproc.extract_doc_pub(
                            false,
                            ListUtil.isEmpty(preoperativeDiscussionLabel) ? ModelStandardKeys.preoperativeDiscussion : preoperativeDiscussionLabel,
                            preoperativeDiscussionContent
                    );
            PreoperativeDiscussionDoc preoperativeDiscussionDoc = ModelDocGenerate.preoperativeDiscussionDocGen(preoperativeDiscussionStructureMap);
            preoperativeDiscussionDoc.setText(preoperativeDiscussionContent);
            operationDoc.setPreoperativeDiscussionDoc(preoperativeDiscussionDoc);

            retList.add(operationDoc);
        }
        return retList;
    }

}